@@ -1,7 +1,6 @@
 "Python script containing functions and classes for general cryptographic use.\nDeveloped on linux, but should work on windows."
 
 # importing libraries
-from curses import keyname
 import os # various file operations and directory walking.
 import rsa # used in Ciphers class for RSA
 from Crypto.Cipher import AES # used for string encryption/decryption
@@ -83,7 +82,6 @@ class Ciphers: # tested
         try:
             assert path is not None
             assert "/." not in path
-            assert get_platform() == "linux" and "/home/" in path
             assert os.path.isfile(path) is True or os.path.isdir(path) is True
             try:
                 with open (path, "rb") as file:
